@@ -1,4 +1,4 @@
-function out = resample_geodata(in,field,newgrid)
+function [out,weights] = resample_geodata(in,field,newgrid,weights)
 % RESAMPLE_GEODATA regrid the data to a new gridsize or fitting to new lat lons
 %
 % PURPOSE:  To resample GRIDDED data according a given gridsize or lat/lon
@@ -17,12 +17,12 @@ function out = resample_geodata(in,field,newgrid)
 %
 %   field       %s          {'field1',etc}; The field/s  you want to regrid
 %
-%   newgrid     %f, or [%f %f], {[newlat],[newlon]} (e.g. newlat = -90:5:90)
+%   newgrid     %f, or [%f %f], {[newlon],[newlat]} (e.g. newlat = -90:5:90)
 %
 %              a) Either make a sqaure grid using a scalar %f. e.g 1deg ->
 %                 2deg (Assumes centered data!)
 %
-%              b) or a 2 element vector [%f %f] means [latstep, lonstep]
+%              b) or a 2 element vector [%f %f] means [lonstep, latstep]
 %                 e.g. 1*1 -> 1.25*2.75 (Assumes centered data!)
 %
 %              c) or {[newlat],[newlon]} if you want to match to a predefined
@@ -55,7 +55,7 @@ function out = resample_geodata(in,field,newgrid)
 % USAGE:         out = resample_geodata(in,{'CC','HCC','MCC','LCC','P','T','Q'},3);
 %         e.g.   out = resample_geodata(in,{'CC','HCC','MCC','LCC','P','T','Q'},[3,5]);
 %                out = resample_geodata(in,{'CC','HCC','MCC','LCC','P','T','Q'},...
-%                        {[ newlats ],[ newlons ]} );
+%                        {[ newlons ],[ newlats ]} );
 %
 %                1st example: Someone wants to resample 7 data fields
 %                in one go to a 3x3 deg grid (the common lat lons are in the structure)
@@ -70,20 +70,24 @@ function out = resample_geodata(in,field,newgrid)
 % $Id: regrid_dataset.m 6417 2011-04-21 06:44:37Z seliasson $
 
 errID = ['atmlab:' mfilename ':badInput'];
-assert(nargin==3,errID,'Incorrect number of input arguments')
+assert(nargin>2,errID,'Incorrect number of input arguments')
 if ~iscell(field), field={field}; end
 
 % rename the structure so nothing is lost after this function
 out = in;
 
 % CHECK input
-sz                                  = check_input(in,field,newgrid,errID);
+sz                = check_input(in,field,newgrid,errID);
 
 % ASSEMBLE_newgrid
-[newlat,newlon]                     = assemble_newgrid(in.lat,in.lon,newgrid,errID);
+[newlon,newlat]   = assemble_newgrid(in.lon,in.lat,newgrid,errID);
 
 % STANDARDIZE "new grid" internally
-[rg_flags,newlat,newlon]            = standardize_geodata(newlat,newlon);
+gridoptions=struct('lat_descend',false,'lon_descend',false,'lon360',false,'silent',true);
+[rg_flags,tmp]    = standardize_geodata(struct('lon',newlon,'lat',newlat),gridoptions);
+newlon=tmp.lon;
+newlat=tmp.lat;
+clear tmp
 
 % LEAVE function if nothing needs to be done
 if isequal(in.lat(:),newlat(:)) && isequal(in.lon(:),newlon(:))
@@ -93,7 +97,7 @@ if isequal(in.lat(:),newlat(:)) && isequal(in.lon(:),newlon(:))
 end
 
 % CHECK WHICH test
-out.method                          = which_test(in.lat,in.lon,newlat,newlon);
+out.method        = which_test(in.lat,in.lon,newlat,newlon);
 
 % PRINT to screen what is about to happen
 if strcmp(out.method,'shift grid')
@@ -115,20 +119,33 @@ elseif strcmp(out.method,'interpolate')
     end
 end
 
+if strcmp(out.method,'coarse grid with area weighting') && ...
+    (~exist('weights','var') || isempty(weights))
+    % do this only once. This saves time if there are more than one field
+    [~,tmp]   = standardize_geodata(struct('lat',in.lat,'lon',in.lon),gridoptions);
+    logtext(1,'getting weights\n')
+    weights = get_weights_for_coarser_grid_withAreaweighting(struct('lat',tmp.lat,'lon',tmp.lon),newlat,newlon);
+end
 %% LOOP over FIELDS to regrid
+
 for F = field
+    logtext(1,'Processing field: "%s"\n',F{1})
     fsz = size(in.(F{1}));
 
     % COLLAPSE data onto the 3rd dimesion
     data = in.(F{1})(:,:,:);
     
     % STANDARDIZE "input" data internally
-    [flags,lat,lon,data]  = standardize_geodata(in.lat,in.lon,data);
-
+    gridoptions=struct('lat_descend',false,'lon_descend',false,'lon360',false,'dimorder','latlon','silent',true);
+    [flags,tmp]   = standardize_geodata(struct('lat',in.lat,'lon',in.lon,'data',data),gridoptions);
+    lat  = tmp.lat;
+    lon  = tmp.lon;
+    data = tmp.data;
+    clear tmp
+    
     % CHECK for every field
     assert(isequal(fsz(1:2),sz(1:2)),...
         errID,'All input fields for processing don''t have matching lat lon dims')
-   
     
     % USE appropriate METHOD
     switch out.method
@@ -140,7 +157,7 @@ for F = field
             data = coarser_grid(struct('lat',lat,'lon',lon,'data',data),newlat,newlon);
         case 'coarse grid with area weighting'
             % successfully tested for 4D data and lon=0:360, lat = end:-1:1
-            data = coarser_grid_withAreaweighting(struct('lat',lat,'lon',lon,'data',data),newlat,newlon);
+            data = coarser_grid_withAreaweighting(struct('lat',lat,'lon',lon,'data',data),weights,newlat,newlon);
         case 'shift grid'
             % successfully: regular, 4D, 
             data = interpolate_grid(struct('lat',lat,'lon',lon,'data',data,'method',intm),newlat,newlon);
@@ -163,7 +180,7 @@ for F = field
         [~,lnindex] = sort(newlon+(newlon<0)*360);
         data = data(:,lnindex,:);
     end
-    if flags.permute
+    if strcmp(flags.dimorder,'lonlat')
         data = permute(data,[2,1,3]);
     end
 
@@ -205,10 +222,10 @@ assert(~any(~isfield(in,{'lat','lon'})),errID,'"lat,lon" are required fields')
 assert(all(ismember(field,fieldnames(in))),errID,'One or more of the specified data fields is missing');
 assert(~isequal([size(in.(field{1}),1),size(in.(field{1}),2)],size(in.lat),size(in.lon)),...
     errID,'function only works on regular grids, i.e. data(lat,lon,...) or data(lon,lat,...)')
-assert(max(diff(in.lat))-min(diff(in.lat))<0.1&&max(diff(in.lon))-min(diff(in.lon))<0.1,...
-    errID,'The input data must be equidegree (constant spacing)')
-assert( (isequal(in.lat,sort(in.lat)) || isequal(in.lat,sort(in.lat,'descend')) ) && ...
-    (isequal(in.lon,sort(in.lon)) || isequal(in.lon,sort(in.lon,'descend')) ),...
+% assert(max(diff(in.lat))-min(diff(in.lat))<0.1&&max(diff(in.lon))-min(diff(in.lon))<0.1,...
+%     errID,'The input data must be equidegree (constant spacing)')
+assert( ( isequal(in.lat,sort(in.lat)) || isequal(in.lat,sort(in.lat,'descend')) ) && ... % lats
+    ( isequal(in.lon,sort(in.lon)) || isequal(in.lon,sort(in.lon,'descend')) ),...        % lons
     errID,'both lat & lon must be ascending or descending')
 sz = size(in.(field{1}));
 assert(isequal([length(in.lat),length(in.lon)],[sz(1),sz(2)]) || ...
@@ -229,7 +246,7 @@ else
 end
 
 
-function [newlat,newlon] = assemble_newgrid(LAT,LON,newgrid,errID)
+function [newlon,newlat] = assemble_newgrid(LON,LAT,newgrid,errID)
 %% ASSEMBLE_newgrid
 % in:    LAT             orig latvector
 %        LON             orig lonvector
@@ -240,8 +257,8 @@ function [newlat,newlon] = assemble_newgrid(LAT,LON,newgrid,errID)
 
 if iscell(newgrid)
     % E.g. for mapping one dataset to anothers lat/lons
-    newlat = newgrid{1};
-    newlon = newgrid{2};
+    newlon = newgrid{1};
+    newlat = newgrid{2};
     assert(max(diff(newlat))-min(diff(newlat))<0.1&&max(diff(newlon))-min(diff(newlon))<0.1,...
         errID,'The input newgrid must be equidegree (constant spacing)')
     
@@ -290,10 +307,10 @@ function method = which_test(LAT,LON,newlat,newlon)
 eps = 1e-5; %this corresponds to 1 meter at the equator
 
 % diff averages
-dnlt = mean(diff(newlat));
-dnln = mean(diff(newlon));
-dlt  = mean(diff(LAT));
-dln  = mean(diff(LON));
+dnlt = mean(abs(diff(newlat)));
+dnln = mean(abs(diff(newlon)));
+dlt  = mean(abs(diff(LAT)));
+dln  = mean(abs(diff(LON)));
 
 % temporay vectors
 nltb   = newlat - dnlt/2;
@@ -364,8 +381,12 @@ LAT=in.lat(:)';
 dn = mean(diff(LON));
 dt = mean(diff(LAT));
 
+% make sure they have the same data class
+newlon=cast(newlon,class(in.lon));
+newlat=cast(newlat,class(in.lat));
+
 while LON(1)>=newlon(1)
-    LON = [LON(1)-dn,LON,LON(end)+dn];
+    LON = [LON(1)-dn,LON,LON(end)+dn]; %#ok<*AGROW>
     data = [data(:,end,:),data,data(:,1,:)];
 end
 while LAT(1)>=newlat(1)
@@ -382,7 +403,7 @@ else
     DATA = zeros([length(newlat),length(newlon),size(data,3)],class(data));
 end
 
-fprintf('Using interpolation method: %s\n',in.method)
+logtext(1,'Using interpolation method: %s\n',in.method)
 for i = 1:size(data,3)
     DATA(:,:,i) = interp2(X,Y,data(:,:,i),XI,YI,in.method);
 end
@@ -409,7 +430,7 @@ if any(isnan(tmpdata(:))), warning(['atmlab:' mfilename ':calculation'],...
         'There are NaNs in the data, and these may lead to biases on the coarser grid'); end
 tmpdata = binned_statistics(tmpdata,{@nanmean});
 
-if ndims(in.data)==2
+if ismatrix(in.data)
     data = cell2mat(tmpdata.mean);
 elseif ndims(in.data)==3
     % make into MATRIX(lat,lat,...)
@@ -423,7 +444,40 @@ elseif ndims(in.data)==3
     end
 end
 
-function data = coarser_grid_withAreaweighting(in,lat,lon)
+function weights = get_weights_for_coarser_grid_withAreaweighting(in,newlat,newlon)
+
+% DETERMINE new grid BOUNDARIES from grid spacing
+gn = mean(diff(newlon));    gt = mean(diff(newlat));
+dn = mean(diff(in.lon)); dt = mean(diff(in.lat));
+if isnan(gt), gt = (in.lat(end)-in.lat(1) + dt);end %incase there's only one latitude
+if isnan(gn), gn = (in.lon(end)-in.lon(1) + dn);end %incase there's only one longitude
+
+lattop = newlat+gt/2+dt;
+latbot = newlat-gt/2;
+lontop = newlon+gn/2+dn;
+lonbot = newlon-gn/2;
+
+weights = cell(length(newlat),length(newlon));
+
+%LOOP over larger grid
+for ii = 1:length(newlat)
+    for jj=1:length(newlon)
+        
+        % GET lats lons in or tangent to grid(i,j)
+        ilon = in.lon >= lonbot(jj) & in.lon < lontop(jj);
+        ilat = in.lat >= latbot(ii) & in.lat < lattop(ii);
+        
+        % find WEIGHTS
+        % A = [x,y,width,height] x,y = bottom corner
+        A = [lonbot(jj),latbot(ii),gn,gt];
+        [x,y] = meshgrid(in.lon(ilon)-dn/2,in.lat(ilat)-dt/2);
+        B = [ x(:), y(:), repmat(dn,length(y(:)),1), repmat(dt,length(x(:)),1)];
+        weights{ii,jj} = rectint(A,B);
+
+    end
+end
+
+function data = coarser_grid_withAreaweighting(in,weights,lat,lon)
 %% COARSER_GRID make a coarse grid from a finer grid
 % method: Uses area weighting for grids that don't fit nicely into each
 % other and assumes local plane assumption, which is good as long as the
@@ -436,10 +490,11 @@ function data = coarser_grid_withAreaweighting(in,lat,lon)
 % preallocate
 if ~islogical(in.data)
     data = zeros([length(lat),length(lon),size(in.data,3)],class(in.data));
-else data = false([length(lat),length(lon),size(in.data,3)]);
+else
+    data = false([length(lat),length(lon),size(in.data,3)]);
 end
 
-polyWeightSum = @(d,w,i)(nansum(d(i).*w(i))./nansum(w(i)));
+polyWeightSum = @(d,w,i)(nansum(single(d(i)).*w(i))./nansum(w(i)));
 
 % DETERMINE new grid BOUNDARIES from grid spacing
 gn = mean(diff(lon)); gt = mean(diff(lat));
@@ -459,13 +514,6 @@ for ii = 1:length(lat)
         % GET lats lons in or tangent to grid(i,j)
         ilon = in.lon >= lonbot(jj) & in.lon < lontop(jj);
         ilat = in.lat >= latbot(ii) & in.lat < lattop(ii);
-        
-        % find WEIGHTS
-        % A = [x,y,width,height] x,y = bottom corner
-        A = [lonbot(jj),latbot(ii),gn,gt];
-        [x,y] = meshgrid(in.lon(ilon)-dn/2,in.lat(ilat)-dt/2);
-        B = [ x(:), y(:), repmat(dn,length(y(:)),1), repmat(dt,length(x(:)),1)];
-        weights = rectint(A,B);
 
         % get data SUBSET
         d = in.data(ilat,ilon,:);
@@ -474,19 +522,20 @@ for ii = 1:length(lat)
         d = permute(d,[3,1,2]);
         
         for kk = 1:size(d,1)
-            data(ii,jj,kk)    = polyWeightSum(d(kk,:),weights,~isnan(d(kk,:)));
+            data(ii,jj,kk)    = polyWeightSum(d(kk,:),weights{ii,jj},~isnan(d(kk,:)));
         end
     end
 end
 
-function data = fine_and_coarse(in,newlat,newlon,method)
-
-data = interpolate_grid(in,newlat,newlon);
-warning('atmlab:resample_geodata:incomplete',...
-    ['Using interpolation (interp2) for grids that are finer in one dimension '...
-    'and coarser in the other. This is NO GOOD for the dimension that is coarser, '...
-    'because of linear interpolation.'])
-return
+% function data = fine_and_coarse(in,newlat,newlon,method)
+% 
+% data = interpolate_grid(in,newlat,newlon);
+% warning('atmlab:resample_geodata:incomplete',...
+%     ['Using interpolation (interp2) for grids that are finer in one dimension '...
+%     'and coarser in the other. This is NO GOOD for the dimension that is coarser, '...
+%     'because of linear interpolation.'])
+% 
+% return
 
 % Code to fix this problem incomplete below:
 
