@@ -11,21 +11,19 @@ function file = append_tickannotations(file,annotations)
 % OUT: file '%s'
 %
 % Created by Salomon Eliasson
-% $Id: append_tickannotations.m 7254 2012-01-31 22:40:28Z seliasson $
+% $Id: append_tickannotations.m 9254 2015-03-25 22:23:08Z seliasson $
 
 % READ OLD FILE
 fid = fopen(file);
-out={};
-while 1
+s = 0; i =1;
+out = cell(1,10);
+while s ~= -1
     s=fgetl(fid);
-    if (s == -1) break; end
-    out{end+1}=s;
+    out{i}=s;
+    i = i+1;
 end
 fclose(fid);
-
-% CHECK INPUT
-assert(sum(~cellfun('isempty', regexp(out,'^[-+]?[0-9]*\.?[0-9]+'))) == length(annotations),...
-    ['gmtlab:' mfilename ':input'],'Number of annotations must match number of ticks')
+out = out(1:i-2);
 
 fid = fopen(file,'w'); x = 1;
 for i = 1:length(out)
