@@ -20,10 +20,14 @@ function C = intersect_unsorted(A, B)
 %   C   cell arary of strings containing only those elements of A occuring
 %       in B
 %
-% $Id: intersect_unsorted.m 7252 2012-01-30 15:18:44Z gerrit $
+% $Id: intersect_unsorted.m 7368 2012-02-23 14:20:01Z gerrit $
 
 n_A = length(A);
 n_B = length(B);
+if n_A*n_B==0
+    C = {};
+    return
+end
 
 k = 0;
 for i = 1:n_A
