@@ -15,11 +15,11 @@ function utc_datestr = iso_timestamp()
 %
 % OUT s     string (character-array) with ISO time
 
-% $Id: iso_timestamp.m 7260 2012-02-01 14:02:51Z gerrit $
+% $Id: iso_timestamp.m 8141 2013-01-24 16:09:17Z gerrit $
 
 utc_time = java.lang.System.currentTimeMillis;
-[utc_date{1:6}] = unixsecs2date(utc_time/1000);
+[utc_date{1:6}] = unixsecs2date(uint32(floor(utc_time/1000)));
 utc_datestr = sprintf('%04d-%02d-%02dT%02d:%02d:%02dZ', ...
-    [utc_date{1:5} round(utc_date{6})]);
+    utc_date{1:6});
 
 end
